aboutsummaryrefslogtreecommitdiff
path: root/src/main.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/main.cpp')
-rw-r--r--src/main.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/main.cpp b/src/main.cpp
index ff5d2a8..e29c8db 100644
--- a/src/main.cpp
+++ b/src/main.cpp
@@ -39,7 +39,7 @@
#include "DBusAPI.h"
#include "RWADBusAdaptor.cpp"
#include "session.h"
-#include "scenes/add_server_wizard/add_server_wizard.h"
+#include "scenes/add_rwahost_wizard/add_rwahost_wizard.h"
#include "scenes/remote_control/remote_control_manager.h"
#include "RWAHostModel.h"
#include "RWAHost.h"
@@ -119,14 +119,14 @@ int main(int argc, char *argv[]) {
main_gui.data(),
SLOT(onRwaHostSelected(QString)));
- // Make 'add_server_wizard' available to QML
- QScopedPointer<Add_Server_wizard> wizard (
- new Add_Server_wizard(&app,
+ // Make 'AddRWAHostWizard' available to QML
+ QScopedPointer<AddRWAHostWizard> wizard (
+ new AddRWAHostWizard(&app,
main_gui.data(),
dbus_api.data())
);
engine.rootContext()->
- setContextProperty("add_server_wizard", wizard.data());
+ setContextProperty("add_rwahost_wizard", wizard.data());
// Make 'remote_control_manager' available to QML
QScopedPointer<RemoteControlManager> remote_mngr (